==> xray_audit-1.0.0-rc1.tar.gz: xray_audit/src/Plugin/tasks/QueryGroup/XrayAuditQueryTaskMediaPlugin.php <==
<?php

namespace Drupal\xray_audit\Plugin\tasks\QueryGroup;

/**
 * Plugin implementation of queries_data_node.
 *
 * @XrayAuditTaskPlugin (
 *   id = "queries_data_media",
 *   label = @Translation("Data about medias"),
 *   description = @Translation("Queries execute on database to get reports about medias."),
 *   group = "queries_data",
 *   sort = 3,
 *   operations = {
 *      "media_types" = {
 *          "label" = "Media types",
 *          "description" = "Media types."
 *       },
 *    },
 *   dependencies = {"media"}
 * )
 */
class XrayAuditQueryTaskMediaPlugin extends XrayAuditQueryTaskPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getDataOperationResult(string $operation = NULL) {
    switch ($operation) {
      case 'media_types':
        return $this->mediasTypes();
    }
    return [];
  }

  /**
   * Media.
   */
  public function mediasTypes() {
    $headerTable = ['id', 'label', 'count'];
    $resultTable = [];

    $query = $this->entityTypeManager->getStorage('media')->getAggregateQuery();
    $aliasCount= 'count';
    $result = $query->groupBy('bundle')->aggregate('mid', 'COUNT', null, $aliasCount)->execute();
    $result_processed = [];
    foreach ($result as $row) {
      $result_processed[$row['bundle']] = $row['count'];
    }
    $medias = $this->entityTypeManager->getStorage('media_type')->loadMultiple();

    foreach ($medias as $key => $media) {
      $resultTable[] = [
        $key,
        $media->label(),
        $result_processed[$key] ?? 0,
      ];
    }
    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildDataPresentationForCli(array $data, string $operation = NULL) {
    // @todo Implement buildDataPresentationForCli() method.
    return '';
  }

}

==> xray_audit-1.1.1.tar.gz: xray_audit/src/Plugin/tasks/QueryGroup/XrayAuditQueryTaskMediaPlugin.php <==
<?php

namespace Drupal\xray_audit\Plugin\tasks\QueryGroup;

/**
 * Plugin implementation of queries_data_node.
 *
 * @XrayAuditTaskPlugin (
 *   id = "queries_data_media",
 *   label = @Translation("Data about medias"),
 *   description = @Translation("Queries execute on database to get reports about medias."),
 *   group = "queries_data",
 *   sort = 3,
 *   operations = {
 *      "media_types" = {
 *          "label" = "Media types",
 *          "description" = "Media types."
 *       },
 *    },
 *   dependencies = {"media"}
 * )
 */
class XrayAuditQueryTaskMediaPlugin extends XrayAuditQueryTaskPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getDataOperationResult(string $operation = NULL) {
    switch ($operation) {
      case 'media_types':
        return $this->mediasTypes();
    }
    return [];
  }

  /**
   * Media.
   *
   * @return array
   *   Data.
   */
  public function mediasTypes() {
    $headerTable = [
      $this->t('id'),
      $this->t('label'),
      $this->t('count'),
    ];
    $resultTable = [];

    $query = $this->entityTypeManager->getStorage('media')->getAggregateQuery();
    $aliasCount = 'count';
    $result = $query->accessCheck(FALSE)
      ->groupBy('bundle')
      ->aggregate('mid', 'COUNT', NULL, $aliasCount)
      ->execute();
    $result_processed = [];
    foreach ($result as $row) {
      $result_processed[$row['bundle']] = $row['count'];
    }
    $medias = $this->entityTypeManager->getStorage('media_type')->loadMultiple();

    foreach ($medias as $key => $media) {
      $resultTable[] = [
        $key,
        $media->label(),
        $result_processed[$key] ?? 0,
      ];
    }
    return [
      'header_table' => $headerTable,
      'results_table' => $resultTable,
    ];
  }

}
